package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.xlk.entity.ChannelCustomer;
import com.yunzhi.marketing.xlk.service.IChannelCustomerService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 渠道报备客户表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-07-19
 */
@RestController
@RequestMapping("/")
public class ChannelCustomerController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(ChannelCustomerController.class);

    @Autowired
    public IChannelCustomerService iChannelCustomerService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/channelCustomer",method= RequestMethod.GET)
    public ResponseBean channelCustomerList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<ChannelCustomer> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<ChannelCustomer> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<ChannelCustomer> result = iChannelCustomerService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelCustomerList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param channelCustomer 实体对象
     * @return
     */
    @RequestMapping(value="/channelCustomer",method= RequestMethod.POST)
    public ResponseBean channelCustomerAdd(@RequestBody ChannelCustomer channelCustomer){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iChannelCustomerService.save(channelCustomer)){
                responseBean.addSuccess(channelCustomer);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelCustomerAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/channelCustomer/{id}", method= RequestMethod.DELETE)
    public ResponseBean channelCustomerDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iChannelCustomerService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelCustomerDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param channelCustomer 实体对象
     * @return
     */
    @RequestMapping(value="/channelCustomer/{id}",method= RequestMethod.PUT)
    public ResponseBean channelCustomerUpdate(@PathVariable Integer id,
                                        @RequestBody ChannelCustomer channelCustomer){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iChannelCustomerService.updateById(channelCustomer)){
                responseBean.addSuccess(channelCustomer);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelCustomerUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/channelCustomer/{id}",method= RequestMethod.GET)
    public ResponseBean channelCustomerGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iChannelCustomerService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("channelCustomerDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
